Skip to contents

Upload a survey from docx format to the Qualtrics library. The questionnaire doc itself will need to be in the Y2 specified format.

Usage

qnr_converter(file_path, api_token)

Arguments

file_path

A string path to the questionnaire docx file.

api_token

A string that is an API token to related the account you want the survey to be uploaded to.

Value

A series of statements updating the user on the converter's progress.

Examples